☰ GDG /
Docstrings (001–005)
#002 gdtest_google #001 gdtest_minimal #003 gdtest_sphinx #004 gdtest_nodocs #005 gdtest_mixed_docs
Layouts (006–013)
#006 gdtest_src_layout #007 gdtest_python_layout #008 gdtest_lib_layout #009 gdtest_hatch #010 gdtest_setuptools_find #012 gdtest_setup_py #011 gdtest_setup_cfg #013 gdtest_auto_discover
Exports (014–017)
#014 gdtest_no_all #016 gdtest_config_exclude #015 gdtest_all_concat #017 gdtest_auto_exclude
Object Types (018–027)
#018 gdtest_small_class #020 gdtest_dataclasses #019 gdtest_big_class #021 gdtest_enums #022 gdtest_typed_containers #023 gdtest_protocols #024 gdtest_descriptors #026 gdtest_nested_class #025 gdtest_dunders #027 gdtest_constants
Directives (028–032)
#028 gdtest_seealso #029 gdtest_nodoc #030 gdtest_user_guide_auto #031 gdtest_user_guide_sections #032 gdtest_user_guide_subdirs
User Guide (033–038)
#033 gdtest_user_guide_explicit #034 gdtest_user_guide_custom_dir #035 gdtest_user_guide_hyphen #036 gdtest_readme_rst #038 gdtest_index_md #037 gdtest_index_qmd
Landing Pages (039–043)
#039 gdtest_no_readme #040 gdtest_index_wins #041 gdtest_index_frontmatter #042 gdtest_full_extras #043 gdtest_github_contrib
Extras & Config (044–050)
#044 gdtest_cli_click #048 gdtest_name_mismatch #046 gdtest_explicit_ref #045 gdtest_cli_nested #047 gdtest_kitchen_sink #049 gdtest_src_big_class #050 gdtest_google_big_class
Cross-Dimension (051–065)
#051 gdtest_user_guide_cli #053 gdtest_src_no_all #052 gdtest_explicit_big_class #055 gdtest_google_seealso #054 gdtest_extras_guide #056 gdtest_setup_cfg_src #057 gdtest_exclude_cli #058 gdtest_src_explicit_ref #059 gdtest_async_funcs #060 gdtest_generators #061 gdtest_overloads #062 gdtest_abstract_props #063 gdtest_multi_inherit #064 gdtest_slots_class #065 gdtest_frozen_dc
API Patterns (066–077)
#066 gdtest_generics #067 gdtest_context_mgr #068 gdtest_decorators #069 gdtest_exceptions #070 gdtest_reexports #071 gdtest_many_exports #072 gdtest_deep_nesting #073 gdtest_long_docs #074 gdtest_many_guides #076 gdtest_flit #077 gdtest_pdm #075 gdtest_many_big_classes
Scale & Stress (078–082)
#078 gdtest_namespace #079 gdtest_monorepo #080 gdtest_multi_module #081 gdtest_src_legacy #082 gdtest_empty_module
Build Systems (083–088)
#083 gdtest_all_private #084 gdtest_duplicate_all #085 gdtest_badge_readme #086 gdtest_math_docs #087 gdtest_mixed_guide_ext #088 gdtest_unicode_docs
Edge Cases (089–095)
#089 gdtest_config_all_on #090 gdtest_config_display #091 gdtest_config_minimal #092 gdtest_config_parser #093 gdtest_config_extra_keys #094 gdtest_github_icon #095 gdtest_source_branch
Config Matrix (096–100)
#096 gdtest_source_path #097 gdtest_source_title #098 gdtest_source_disabled #099 gdtest_sidebar_disabled #100 gdtest_sidebar_min_items
Config Options (101–125)
#102 gdtest_cli_name #103 gdtest_dynamic_false #101 gdtest_sidebar_float #104 gdtest_parser_google #105 gdtest_parser_sphinx #106 gdtest_display_name #107 gdtest_funding #108 gdtest_authors_multi #109 gdtest_no_darkmode #110 gdtest_exclude_list #111 gdtest_jupyter_kernel #112 gdtest_config_sections #113 gdtest_config_ug_string #114 gdtest_config_ug_list #115 gdtest_config_changelog #116 gdtest_config_reference #117 gdtest_config_combo_a
#121 gdtest_config_combo_e FAIL
#118 gdtest_config_combo_b #119 gdtest_config_combo_c #120 gdtest_config_combo_d #122 gdtest_config_combo_f #123 gdtest_attribution_on #124 gdtest_attribution_off #125 gdtest_rst_versionadded
Docstring Richness (126–150)
#126 gdtest_rst_deprecated #127 gdtest_rst_note #128 gdtest_rst_warning #129 gdtest_rst_tip #130 gdtest_rst_caution #131 gdtest_rst_danger #132 gdtest_rst_important #134 gdtest_directives #133 gdtest_rst_mixed_dirs #135 gdtest_sphinx_func_role #136 gdtest_sphinx_class_role #138 gdtest_sphinx_meth_role #137 gdtest_sphinx_exc_role #139 gdtest_sphinx_mixed_roles #140 gdtest_numpy_rich #142 gdtest_sphinx_rich #141 gdtest_google_rich #143 gdtest_docstring_examples #144 gdtest_examples_rst_repro #145 gdtest_docstring_notes #146 gdtest_docstring_warnings #147 gdtest_docstring_references #148 gdtest_docstring_seealso #149 gdtest_docstring_math #150 gdtest_docstring_tables
UG Variations (151–165)
#151 gdtest_docstring_combo #152 gdtest_ug_auto #153 gdtest_ug_numbered #154 gdtest_ug_sections_fm #155 gdtest_ug_subdirs #156 gdtest_ug_custom_dir #157 gdtest_ug_deep_nest #158 gdtest_ug_mixed_ext #160 gdtest_ug_explicit_order #159 gdtest_ug_many_pages #161 gdtest_ug_single_page #162 gdtest_ug_no_frontmatter #164 gdtest_ug_with_images #163 gdtest_ug_with_code #165 gdtest_ug_hyphen_dir
Custom Sections (166–175)
#166 gdtest_ug_combo #167 gdtest_sec_examples #168 gdtest_sec_tutorials #169 gdtest_sec_recipes #170 gdtest_sec_blog #171 gdtest_sec_faq #172 gdtest_sec_multi #173 gdtest_sec_navbar_after #174 gdtest_sec_with_ug #175 gdtest_sec_with_ref
Reference Config (176–185)
#176 gdtest_sec_deep #177 gdtest_sec_index_opt #178 gdtest_sec_index_hero #180 gdtest_custom_passthrough_navbar #179 gdtest_sec_sidebar_single #181 gdtest_custom_raw_navbar_after #182 gdtest_custom_mixed_modes #184 gdtest_custom_basename_output #183 gdtest_custom_nested_combo #185 gdtest_custom_nested_output
Site Theming (186–195)
#186 gdtest_custom_missing_dir_combo #188 gdtest_ref_members_false #187 gdtest_ref_explicit #189 gdtest_ref_mixed #190 gdtest_ref_reorder #192 gdtest_ref_single_section #191 gdtest_ref_sectioned #193 gdtest_ref_module_expand #194 gdtest_ref_big_class #195 gdtest_ref_multi_big
Stress Tests (196–200)
#196 gdtest_ref_title #197 gdtest_theme_cosmo #198 gdtest_theme_lumen #199 gdtest_theme_cerulean #200 gdtest_toc_disabled #201 gdtest_toc_depth #202 gdtest_toc_title #203 gdtest_site_combo #204 gdtest_display_badges #205 gdtest_display_authors #206 gdtest_display_funding #207 gdtest_stress_all_config #208 gdtest_stress_all_docstr #209 gdtest_stress_all_ug #210 gdtest_stress_all_sections #211 gdtest_stress_everything #212 gdtest_src_google_seealso #213 gdtest_hatch_nodoc #214 gdtest_pdm_big_class #215 gdtest_flit_enums #216 gdtest_namespace_ug #217 gdtest_ug_subdir_numbered #218 gdtest_homepage_ug #220 gdtest_logo #221 gdtest_hero_basic #222 gdtest_hero_readme_badges #219 gdtest_long_names #223 gdtest_hero_disabled #224 gdtest_hero_custom #225 gdtest_hero_wordmark #226 gdtest_hero_no_logo #227 gdtest_hero_explicit_badges #228 gdtest_hero_index_qmd #229 gdtest_hero_auto_logo #230 gdtest_md_disabled #231 gdtest_md_no_widget #232 gdtest_announce_simple #233 gdtest_announce_dict #234 gdtest_announce_disabled #235 gdtest_gradient_sky #236 gdtest_gradient_peach #237 gdtest_gradient_prism #238 gdtest_gradient_lilac #239 gdtest_gradient_slate #240 gdtest_gradient_honey #241 gdtest_gradient_dusk #242 gdtest_gradient_mint #243 gdtest_gradient_navbar #244 gdtest_gradient_both #245 gdtest_gradient_mixed #246 gdtest_gradient_no_dismiss #247 gdtest_header_text #248 gdtest_header_list #249 gdtest_header_file #250 gdtest_navbar_color #251 gdtest_navbar_color_light #252 gdtest_navbar_color_dark #253 gdtest_navbar_color_same #254 gdtest_navbar_color_split #256 gdtest_stress_everything_q #255 gdtest_kitchen_sink_q #257 gdtest_seealso_desc #258 gdtest_numpy_seealso_desc #259 gdtest_interlinks_prose #260 gdtest_autolink #261 gdtest_skill_default #262 gdtest_skill_curated #264 gdtest_skill_disabled #263 gdtest_skill_config #265 gdtest_skill_rich #266 gdtest_skill_combo #267 gdtest_skill_complex #268 gdtest_i18n_french #269 gdtest_i18n_japanese #270 gdtest_i18n_arabic #271 gdtest_code_cells #273 gdtest_page_tags #274 gdtest_page_status #272 gdtest_nav_icons #275 gdtest_tag_location #277 gdtest_homepage_ug_subdirs #276 gdtest_icon_shortcode #278 gdtest_gt_tables #281 gdtest_homepage_wide #282 gdtest_interlinks_userguide #279 gdtest_scale_to_fit #280 gdtest_scale_min_scale #283 gdtest_code_span_headings #286 gdtest_namespace_src #284 gdtest_sec_blog_user_index #285 gdtest_sec_dir_titles #287 gdtest_auto_include #288 gdtest_no_auto_exclude #290 gdtest_tbl_shortcode #292 gdtest_hr_shortcode #293 gdtest_accent_color #294 gdtest_keys_shortcode #291 gdtest_tbl_explorer #289 gdtest_tbl_preview #295 gdtest_inline_methods #296 gdtest_inline_always #297 gdtest_inline_never #298 gdtest_inline_threshold #299 gdtest_ref_inherited_explicit #300 gdtest_ref_include_inherited #302 gdtest_details_shortcode #304 gdtest_lightbox #303 gdtest_termshow #301 gdtest_mock_code #305 gdtest_hero_no_name #306 gdtest_sec_nested_tags #307 gdtest_sec_xref_subdirs #308 gdtest_bibliography #309 gdtest_bibliography_csl #311 gdtest_go_cli #310 gdtest_custom_css #312 gdtest_ug_dark_assets #313 gdtest_code_include #314 gdtest_ug_mixed_subdir_order #315 gdtest_type_aliases #316 gdtest_complete_docstrings #317 gdtest_marimo #318 gdtest_no_breadcrumbs #319 gdtest_mcp
318/319 built ⏱ 56.2s 🧪 16/17

ConnectionId

An opaque handle for a single pooled connection.

Usage

ConnectionId()

Connection IDs are generated by the pool and are unique within the lifetime of the process. They appear in log messages and health-check output, so they are strings rather than integers for readability.

See Also

Connection
get_connection()

Methods

Name Description
__add__() Return self+value.
__contains__() Return bool(key in self).
__eq__() Return self==value.
__format__() Return a formatted version of the string as described by format_spec.
__ge__() Return self>=value.
__getitem__() Return self[key].
__gt__() Return self>value.
__iter__() Implement iter(self).
__le__() Return self<=value.
__len__() Return len(self).
__lt__() Return self<value.
__mod__() Return self%value.
__mul__() Return self*value.
__ne__() Return self!=value.
__new__() Create and return a new object. See help(type) for accurate signature.
__repr__() Return repr(self).
__rmod__() Return value%self.
__rmul__() Return value*self.
__sizeof__() Return the size of the string in memory, in bytes.
__str__() Return str(self).
capitalize() Return a capitalized version of the string.
casefold() Return a version of the string suitable for caseless comparisons.
center() Return a centered string of length width.
count() Return the number of non-overlapping occurrences of substring sub in string S[start:end].
encode() Encode the string using the codec registered for encoding.
endswith() Return True if the string ends with the specified suffix, False otherwise.
expandtabs() Return a copy where all tab characters are expanded using spaces.
find() Return the lowest index in S where substring sub is found, such that sub is contained within S[start:end].
format() Return a formatted version of the string, using substitutions from args and kwargs.
format_map() Return a formatted version of the string, using substitutions from mapping.
index() Return the lowest index in S where substring sub is found, such that sub is contained within S[start:end].
isalnum() Return True if the string is an alpha-numeric string, False otherwise.
isalpha() Return True if the string is an alphabetic string, False otherwise.
isascii() Return True if all characters in the string are ASCII, False otherwise.
isdecimal() Return True if the string is a decimal string, False otherwise.
isdigit() Return True if the string is a digit string, False otherwise.
isidentifier() Return True if the string is a valid Python identifier, False otherwise.
islower() Return True if the string is a lowercase string, False otherwise.
isnumeric() Return True if the string is a numeric string, False otherwise.
isprintable() Return True if all characters in the string are printable, False otherwise.
isspace() Return True if the string is a whitespace string, False otherwise.
istitle() Return True if the string is a title-cased string, False otherwise.
isupper() Return True if the string is an uppercase string, False otherwise.
join() Concatenate any number of strings.
ljust() Return a left-justified string of length width.
lower() Return a copy of the string converted to lowercase.
lstrip() Return a copy of the string with leading whitespace removed.
maketrans() Return a translation table usable for str.translate().
partition() Partition the string into three parts using the given separator.
removeprefix() Return a str with the given prefix string removed if present.
removesuffix() Return a str with the given suffix string removed if present.
replace() Return a copy with all occurrences of substring old replaced by new.
rfind() Return the highest index in S where substring sub is found, such that sub is contained within S[start:end].
rindex() Return the highest index in S where substring sub is found, such that sub is contained within S[start:end].
rjust() Return a right-justified string of length width.
rpartition() Partition the string into three parts using the given separator.
rsplit() Return a list of the substrings in the string, using sep as the separator string.
rstrip() Return a copy of the string with trailing whitespace removed.
split() Return a list of the substrings in the string, using sep as the separator string.
splitlines() Return a list of the lines in the string, breaking at line boundaries.
startswith() Return True if the string starts with the specified prefix, False otherwise.
strip() Return a copy of the string with leading and trailing whitespace removed.
swapcase() Convert uppercase characters to lowercase and lowercase characters to uppercase.
title() Return a version of the string where each word is titlecased.
translate() Replace each character in the string using the given translation table.
upper() Return a copy of the string converted to uppercase.
zfill() Pad a numeric string with zeros on the left, to fill a field of the given width.

__add__()

Return self+value.

Usage

__add__(value)

__contains__()

Return bool(key in self).

Usage

__contains__(key)

__eq__()

Return self==value.

Usage

__eq__(value)

__format__()

Return a formatted version of the string as described by format_spec.

Usage

__format__(format_spec)

__ge__()

Return self>=value.

Usage

__ge__(value)

__getitem__()

Return self[key].

Usage

__getitem__(key)

__gt__()

Return self>value.

Usage

__gt__(value)

__iter__()

Implement iter(self).

Usage

__iter__()

__le__()

Return self<=value.

Usage

__le__(value)

__len__()

Return len(self).

Usage

__len__()

__lt__()

Return self<value.

Usage

__lt__(value)

__mod__()

Return self%value.

Usage

__mod__(value)

__mul__()

Return self*value.

Usage

__mul__(value)

__ne__()

Return self!=value.

Usage

__ne__(value)

__new__()

Create and return a new object. See help(type) for accurate signature.

Usage

__new__(*args, **kwargs)

__repr__()

Return repr(self).

Usage

__repr__()

__rmod__()

Return value%self.

Usage

__rmod__(value)

__rmul__()

Return value*self.

Usage

__rmul__(value)

__sizeof__()

Return the size of the string in memory, in bytes.

Usage

__sizeof__()

__str__()

Return str(self).

Usage

__str__()

capitalize()

Return a capitalized version of the string.

Usage

capitalize()

More specifically, make the first character have upper case and the rest lower case.


casefold()

Return a version of the string suitable for caseless comparisons.

Usage

casefold()

center()

Return a centered string of length width.

Usage

center(width, fillchar=" ")

Padding is done using the specified fill character (default is a space).


count()

Return the number of non-overlapping occurrences of substring sub in string S[start:end].

Usage

count()

Optional arguments start and end are interpreted as in slice notation.


encode()

Encode the string using the codec registered for encoding.

Usage

encode(encoding="utf-8", errors="strict")

encoding The encoding in which to encode the string. errors The error handling scheme to use for encoding errors. The default is ‘strict’ meaning that encoding errors raise a UnicodeEncodeError. Other possible values are ‘ignore’, ‘replace’ and ‘xmlcharrefreplace’ as well as any other name registered with codecs.register_error that can handle UnicodeEncodeErrors.


endswith()

Return True if the string ends with the specified suffix, False otherwise.

Usage

endswith()

suffix A string or a tuple of strings to try. start Optional start position. Default: start of the string. end Optional stop position. Default: end of the string.


expandtabs()

Return a copy where all tab characters are expanded using spaces.

Usage

expandtabs(tabsize=8)

If tabsize is not given, a tab size of 8 characters is assumed.


find()

Return the lowest index in S where substring sub is found, such that sub is contained within S[start:end].

Usage

find()

Optional arguments start and end are interpreted as in slice notation. Return -1 on failure.


format()

Return a formatted version of the string, using substitutions from args and kwargs.

Usage

format(*args, **kwargs)

The substitutions are identified by braces (‘{’ and ‘}’).


format_map()

Return a formatted version of the string, using substitutions from mapping.

Usage

format_map(mapping)

The substitutions are identified by braces (‘{’ and ‘}’).


index()

Return the lowest index in S where substring sub is found, such that sub is contained within S[start:end].

Usage

index()

Optional arguments start and end are interpreted as in slice notation. Raises ValueError when the substring is not found.


isalnum()

Return True if the string is an alpha-numeric string, False otherwise.

Usage

isalnum()

A string is alpha-numeric if all characters in the string are alpha-numeric and there is at least one character in the string.


isalpha()

Return True if the string is an alphabetic string, False otherwise.

Usage

isalpha()

A string is alphabetic if all characters in the string are alphabetic and there is at least one character in the string.


isascii()

Return True if all characters in the string are ASCII, False otherwise.

Usage

isascii()

ASCII characters have code points in the range U+0000-U+007F. Empty string is ASCII too.


isdecimal()

Return True if the string is a decimal string, False otherwise.

Usage

isdecimal()

A string is a decimal string if all characters in the string are decimal and there is at least one character in the string.


isdigit()

Return True if the string is a digit string, False otherwise.

Usage

isdigit()

A string is a digit string if all characters in the string are digits and there is at least one character in the string.


isidentifier()

Return True if the string is a valid Python identifier, False otherwise.

Usage

isidentifier()

Call keyword.iskeyword(s) to test whether string s is a reserved identifier, such as “def” or “class”.


islower()

Return True if the string is a lowercase string, False otherwise.

Usage

islower()

A string is lowercase if all cased characters in the string are lowercase and there is at least one cased character in the string.


isnumeric()

Return True if the string is a numeric string, False otherwise.

Usage

isnumeric()

A string is numeric if all characters in the string are numeric and there is at least one character in the string.


isprintable()

Return True if all characters in the string are printable, False otherwise.

Usage

isprintable()

A character is printable if repr() may use it in its output.


isspace()

Return True if the string is a whitespace string, False otherwise.

Usage

isspace()

A string is whitespace if all characters in the string are whitespace and there is at least one character in the string.


istitle()

Return True if the string is a title-cased string, False otherwise.

Usage

istitle()

In a title-cased string, upper- and title-case characters may only follow uncased characters and lowercase characters only cased ones.


isupper()

Return True if the string is an uppercase string, False otherwise.

Usage

isupper()

A string is uppercase if all cased characters in the string are uppercase and there is at least one cased character in the string.


join()

Concatenate any number of strings.

Usage

join(iterable)

The string whose method is called is inserted in between each given string. The result is returned as a new string.

Examples

‘.’.join([‘ab’, ‘pq’, ‘rs’]) -> ‘ab.pq.rs’

ljust()

Return a left-justified string of length width.

Usage

ljust(width, fillchar=" ")

Padding is done using the specified fill character (default is a space).


lower()

Return a copy of the string converted to lowercase.

Usage

lower()

lstrip()

Return a copy of the string with leading whitespace removed.

Usage

lstrip(chars=None)

If chars is given and not None, remove characters in chars instead.


maketrans()

Return a translation table usable for str.translate().

Usage

maketrans()

If there is only one argument, it must be a dictionary mapping Unicode ordinals (integers) or characters to Unicode ordinals, strings or None. Character keys will be then converted to ordinals. If there are two arguments, they must be strings of equal length, and in the resulting dictionary, each character in x will be mapped to the character at the same position in y. If there is a third argument, it must be a string, whose characters will be mapped to None in the result.


partition()

Partition the string into three parts using the given separator.

Usage

partition(sep)

This will search for the separator in the string. If the separator is found, returns a 3-tuple containing the part before the separator, the separator itself, and the part after it.

If the separator is not found, returns a 3-tuple containing the original string and two empty strings.


removeprefix()

Return a str with the given prefix string removed if present.

Usage

removeprefix(prefix)

If the string starts with the prefix string, return string[len(prefix):]. Otherwise, return a copy of the original string.


removesuffix()

Return a str with the given suffix string removed if present.

Usage

removesuffix(suffix)

If the string ends with the suffix string and that suffix is not empty, return string[:-len(suffix)]. Otherwise, return a copy of the original string.


replace()

Return a copy with all occurrences of substring old replaced by new.

Usage

replace(old, new, /, count=-1)

count Maximum number of occurrences to replace. -1 (the default value) means replace all occurrences.

If the optional argument count is given, only the first count occurrences are replaced.


rfind()

Return the highest index in S where substring sub is found, such that sub is contained within S[start:end].

Usage

rfind()

Optional arguments start and end are interpreted as in slice notation. Return -1 on failure.


rindex()

Return the highest index in S where substring sub is found, such that sub is contained within S[start:end].

Usage

rindex()

Optional arguments start and end are interpreted as in slice notation. Raises ValueError when the substring is not found.


rjust()

Return a right-justified string of length width.

Usage

rjust(width, fillchar=" ")

Padding is done using the specified fill character (default is a space).


rpartition()

Partition the string into three parts using the given separator.

Usage

rpartition(sep)

This will search for the separator in the string, starting at the end. If the separator is found, returns a 3-tuple containing the part before the separator, the separator itself, and the part after it.

If the separator is not found, returns a 3-tuple containing two empty strings and the original string.


rsplit()

Return a list of the substrings in the string, using sep as the separator string.

Usage

rsplit(sep=None, maxsplit=-1)

sep The separator used to split the string.

When set to None (the default value), will split on any
whitespace character (including \n \r \t \f and spaces) and
will discard empty strings from the result.

maxsplit Maximum number of splits. -1 (the default value) means no limit.

Splitting starts at the end of the string and works to the front.


rstrip()

Return a copy of the string with trailing whitespace removed.

Usage

rstrip(chars=None)

If chars is given and not None, remove characters in chars instead.


split()

Return a list of the substrings in the string, using sep as the separator string.

Usage

split(sep=None, maxsplit=-1)

sep The separator used to split the string.

When set to None (the default value), will split on any
whitespace character (including \n \r \t \f and spaces) and
will discard empty strings from the result.

maxsplit Maximum number of splits. -1 (the default value) means no limit.

Splitting starts at the front of the string and works to the end.

Note, str.split() is mainly useful for data that has been intentionally delimited. With natural text that includes punctuation, consider using the regular expression module.


splitlines()

Return a list of the lines in the string, breaking at line boundaries.

Usage

splitlines(keepends=False)

Line breaks are not included in the resulting list unless keepends is given and true.


startswith()

Return True if the string starts with the specified prefix, False otherwise.

Usage

startswith()

prefix A string or a tuple of strings to try. start Optional start position. Default: start of the string. end Optional stop position. Default: end of the string.


strip()

Return a copy of the string with leading and trailing whitespace removed.

Usage

strip(chars=None)

If chars is given and not None, remove characters in chars instead.


swapcase()

Convert uppercase characters to lowercase and lowercase characters to uppercase.

Usage

swapcase()

title()

Return a version of the string where each word is titlecased.

Usage

title()

More specifically, words start with uppercased characters and all remaining cased characters have lower case.


translate()

Replace each character in the string using the given translation table.

Usage

translate(table)

table Translation table, which must be a mapping of Unicode ordinals to Unicode ordinals, strings, or None.

The table must implement lookup/indexing via getitem, for instance a dictionary or list. If this operation raises LookupError, the character is left untouched. Characters mapped to None are deleted.


upper()

Return a copy of the string converted to uppercase.

Usage

upper()

zfill()

Pad a numeric string with zeros on the left, to fill a field of the given width.

Usage

zfill(width)

The string is never truncated.