reinitialize()
Reset the global connection pool.
Usage
reinitialize()Call this after os.fork() to avoid sharing file descriptors between parent and child processes. All existing connections are closed and new ones are established.
Notes
This is a no-op if the pool has not been initialized yet.